function [xa,A]=blue(xb,B,R,d,G)
%%%%%%%%%%%%%%%%%/
%  blue
%
% Methode BLUE (Best Linear Unbiased Estimation)
%
%  xb : ebauche, vecteur colonne de dimension ncont
%  B : matrice des covariances d'erreur d'ebauche (ncont x ncont)
%  R : matrice des covariance d'erreur d'observation (nobs x nobs) 
%  d : innovation, vecteur colone de dimension nobs
%  G : operateur d'observation linearise, matrice (nobs x ncont) 
%  
%  xa : analyse, vecteur colonne de dimension ncont
%  A : matrice des covariances d'erreur d'analyse (ncont x ncont)
% 
% K : matrice de gain (ncont x nobs)
%    suivant les dimensions ncont et nobs on choisira entre 
%      K = B*G'*inv(G*B*G'+R)
%    equivalent a 
%      K = inv(inv(B)+G'*inv(R)*G)*G'*inv(R)       
%%%%%%%%%%%%%%%%%%%%%%%%%%/

% matrice de gain K : premiere expression 
K=B*G'*inv(G*B*G'+R);

% matrice de gain K : deuxieme expression 
% K=inv(inv(B)+G'*inv(R)*G)*G'*inv(R);

% analyse
xa=xb+K*d;

% matrice des covariances d'erreur d'analyse
A=B-K*G*B;

endfunction