function main_ressaut
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  pour Octave                                       ________________||
%  cree le        30/03/2012 par O. THUAL          /      |          ||
%                                          W <----|       |          ||
%  Mesure de la vitesse d'un ressaut              |   hR  |          ||
%          hL UL              _________________ _/        |          ||
%  W = -  =======                ---> UL   | hL           |          ||
%         hR - hL             =======================================||
% 
%  modifie le  22 mars 2013 par O. THUAL
%
%  hL : hauteur a gauche du ressaut
%  UL : vitesse a droite du ressaut
%  hR : hauteur a droite du ressaut
%  UR = 0 : la vitesse est nulle entre le ressaut et la vanne fermee
% 
%   W : vitesse du ressaut
%
% Apres la fermeture de la vanne on mesure la vitesse W 
%     et on estime a l'oeil nu la hauteur hR
% 
%  sigBhR : erreur d'ebauche hR
%  sigRW : erreur de mesure 
%
%  Etat vrai :  x^t = hR^t
%  Ebauche   :  x^b=  hR^b
%
%  Mesure : y^o = W^o
%              obtenue a partir de l'etat vrai
%              en ajoutant un erreur gaussienne
%              d'ecart-type sigR a l'observation vraie
%
%  Operateur d'observation : 
%  y = calG(x)   <=>   W = -hL UL / (hR - hL)
%                      avec hL et UL connus
%
%  Operateur d'observation linearise : 
%  dy =  G dx  <=>  dW = calG'(hR) dhR 
%    avec G = calG'(hR) = dW/dhR = hL UL / (hR - hL)^2
% 
%
% Matrices de covariances des erreurs d'ebauche :                        
%     B =  sigBhR^2
%
% Matrices de covariances des erreurs d'observation :  
%    R =  sigRW^2
%  
% Methode de la fonction cout incrementale
% Jinc(dx)= 1/2 dx' B^-1 dx + 1/2 [d- G dx]' R^-1 [d- G dx]
% ou l'innovation est  d= y^o - calG(x^b)  
%
% Analyse :  x^a = [alpha^a; P^a] = x^b + K d
% ou la matrice de gain est K = B G' (G B G' + R)^-1 
%               ou encore  K = (B^-1 + G' R^-1 G)^-1 G' R^-1
%
% Visualisation des resultats : 
%    Etat vrai : bleu,  Ebauche : noir,  Analyse : rouge
%
% Fonctions appellees par le programme : 
%
% init_ressaut.m : regler les parametres dans ce fichier
% jumelles_ressaut.m : realiser une experience jumelle
% blue.m : methode BLUE (Best Linear Unbiased Estimation)
% calG_ressaut.m : operateur d'observation non lineaire
% G_ressaut.m : operateur d'observation linearise 
% visual_ressaut.m : visualisation des resultats
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Close figures
close all

% Clear variables
clear all

% variables globales 
global cumul   % cumul d'erreur pour calcul de score
global visu   %  pour desactiver les traces des figures   

% Display title
disp("Assimilation de donees pour le probleme du ressaut")

%%%%%/ Parametres de reglagge d'experiences %%%%%%%%%
jtirmax=10; % nombre de tirages aleatoires
visu=true;     % avec figures si visu=true , sans si visu=false
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%
% Lancement de l'experience 
%%%%%%%%%%%%%%/


% Lancement du generateur de tirage aleatoire
randn('seed');

% Boucle sur tirages aleatoires d'experiences jumelles 
%%%%%%%%%%%%%%%%%%%%%%%%%%%/


cumul=0;  % intialisation de cumul pour le calcul de score

for jtir=1:jtirmax
   
   % experience jumelle
   jumelles_ressaut(jtir);
   
   % mettre flag=1 pour temporisation de l'affichage des figures
   flag=0; 
   if(flag==1)   
      input('Taper sur la touche ''Enter'' pour la figure suivante :' )
   end
   
end

% impression du score calcule dans jumelles.sci
score=sqrt(cumul/jtirmax);
disp(sprintf('score =%5.3g',score))


